#!/usr/bin/env python3
"""
Traceroute Implementation
Parameters:
    - IP: Target IP address
Requires root/admin privileges
"""
from scapy.all import *
import argparse
import sys

def traceroute(ip):
    try:
        ttl = 1
        while True:
            # Create packet with increasing TTL
            pkt = IP(dst=ip, ttl=ttl) / ICMP()
            
            # Send packet and wait for response
            reply = sr1(pkt, verbose=0, timeout=2)
            
            if reply is None:
                print(f"{ttl}: *")
            else:
                print(f"{ttl}: {reply.src}")
                
            if reply and reply.src == ip:
                break
                
            ttl += 1
            if ttl > 30:  # Maximum hops
                print("Reached maximum hops")
                break
    except Exception as e:
        print(f"Error: {str(e)}")
        sys.exit(1)

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Traceroute Tool")
    parser.add_argument("ip", help="Target IP address")
    args = parser.parse_args()
    
    traceroute(args.ip)
